@@ -497,10 +497,12 @@ class TestConstrainedType(unittest.TestCase):
                     obj = _create_object(_basic_type=basic_type)
 
                     self.assertEqual(obj.constraint_unit.label, 'Unit-Label')
-                    self.assertEqual(obj.constraint_unit.unit_components[0].exponent, 1)
-                    self.assertEqual(obj.constraint_unit.unit_components[0].factor, 1)
-                    self.assertEqual(obj.constraint_unit.unit_components[0].offset, 0)
-                    self.assertEqual(obj.constraint_unit.unit_components[0].si_unit.value, '-')
+                    self.assertEqual(obj.constraint_unit.units[0].factor, 1)
+                    self.assertEqual(obj.constraint_unit.units[0].offset, 0)
+
+                    self.assertEqual(obj.constraint_unit.units[0].base_unit.exponent, 1)
+                   
+                    self.assertEqual(obj.constraint_unit.units[0].base_unit.si_unit.value, '-')
                 else:
                     with self.assertWarns(ConstraintTypeWarning):
                         obj = _create_object(_basic_type=basic_type)
