@@ -10,6 +10,7 @@ ________________________________________________________________________
 :file:    sila_server.py
 :authors: Mark Doerr
           Timm Severin
+          Lukas Broming
 
 :date: (creation)          2018-11-28
 :date: (last modification) 2019-08-27
@@ -24,7 +25,7 @@ ________________________________________________________________________
 ________________________________________________________________________
 """
 
-__version__ = "0.2.0"
+__version__ = "0.2.4"
 
 import os
 
@@ -88,7 +89,8 @@ class SiLA2Server:
                  vendor_url: str = "",
                  ip: str = '127.0.0.1', port: int = 50051,
                  key_file: Optional[str] = 'sila_server.key', cert_file: Optional[str] = 'sila_server.crt',
-                 simulation_mode: bool = True):
+                 simulation_mode: bool = True,
+                 server_hostname: str = None):
         """
         Initialising and starting the gRPC server, which is the core of the SiLA server.
 
@@ -103,6 +105,7 @@ class SiLA2Server:
         :param port: Server port number
         :param key_file: Filename of private server key
         :param cert_file: Filename of server certificate
+        :param server_hostname: Server host name (DNS)
         """
 
         # read default values from config file
@@ -128,6 +131,8 @@ class SiLA2Server:
         # Networking
         self.server_ip = ip
         self.server_port = port
+        self.server_hostname = server_hostname
+        # self.server_description = description # Not needed. Cannot set this again!
 
         # Encryption
         if key_file is None or cert_file is None:
@@ -247,15 +252,16 @@ class SiLA2Server:
         self.grpc_server.start()
 
         # enabling zeroconf/Bonjour Service detection
-        service_detection = SiLA2ServiceDetection()
-        service_detection.registerService(
-            service_name=self.SiLAService_feature.server_name,
+        self.service_detection = SiLA2ServiceDetection()
+        self.service_detection.register_service(
             IP=self.server_ip,
             port=self.server_port,
-            server_uuid=self.SiLAService_feature.server_UUID
+            description={'version': __version__, 'descr1': self.SiLAService_feature.server_name, 'descr2': self.server_description},
+            server_uuid=self.SiLAService_feature.server_UUID,
+            server_hostname=self.server_hostname
         )
 
-        print("Server '{server_name}' started!".format(server_name=self.SiLAService_feature.server_name))
+        print(f"Server '{self.SiLAService_feature.server_name}' started!")
         if block:
             print("Please press ctrl-c to stop...")
             try:
@@ -264,6 +270,7 @@ class SiLA2Server:
             except KeyboardInterrupt:
                 self.grpc_server.stop(0)
 
+
     def stop_grpc_server(self, force: bool = False) -> None:
         """
         Immediately stops the grpc server.
